@@ -96,9 +96,9 @@ def load_phm(return_x_y = False):
     """
     module_path = dirname(__file__)
 
-    fdescr_name = join(module_path, 'descr', 'phm.rst')
-    with open(fdescr_name, encoding='utf8') as f:
-        descr_text = f.read()
+    # fdescr_name = join(module_path, 'descr', 'phm.rst')
+    # with open(fdescr_name, encoding='utf8') as f:
+        # descr_text = f.read()
 
     data_file_name = join(module_path, 'data/phm', 'phm_RIGHT_RPhase_FB.csv')
     dataset = pd.read_csv(data_file_name, header=0, delimiter=',')
